pub struct RemotePartitionConfig {
pub home_cluster: String,
pub home_spu_key: String,
pub home_spu_id: i32,
pub home_spu_endpoint: String,
pub target: bool,
}Fields
home_cluster: Stringhome_spu_key: Stringhome_spu_id: i32home_spu_endpoint: Stringtarget: boolTrait Implementations
Sourceimpl Clone for RemotePartitionConfig
impl Clone for RemotePartitionConfig
Sourcefn clone(&self) -> RemotePartitionConfig
fn clone(&self) -> RemotePartitionConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemotePartitionConfig
impl Debug for RemotePartitionConfig
Sourceimpl Decoder for RemotePartitionConfig
impl Decoder for RemotePartitionConfig
Sourceimpl Default for RemotePartitionConfig
impl Default for RemotePartitionConfig
Sourcefn default() -> RemotePartitionConfig
fn default() -> RemotePartitionConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RemotePartitionConfig
impl<'de> Deserialize<'de> for RemotePartitionConfig
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RemotePartitionConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RemotePartitionConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for RemotePartitionConfig
impl Display for RemotePartitionConfig
Sourceimpl Encoder for RemotePartitionConfig
impl Encoder for RemotePartitionConfig
impl Eq for RemotePartitionConfig
Sourceimpl JsonSchema for RemotePartitionConfig
impl JsonSchema for RemotePartitionConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemotePartitionConfig
impl PartialEq for RemotePartitionConfig
Sourceimpl Serialize for RemotePartitionConfig
impl Serialize for RemotePartitionConfig
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for RemotePartitionConfig