pub struct CompressionConfig {
pub type_: CompressionAlgorithm,
}Fields
type_: CompressionAlgorithmTrait Implementations
Sourceimpl Clone for CompressionConfig
impl Clone for CompressionConfig
Sourcefn clone(&self) -> CompressionConfig
fn clone(&self) -> CompressionConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompressionConfig
impl Debug for CompressionConfig
Sourceimpl Default for CompressionConfig
impl Default for CompressionConfig
Sourcefn default() -> CompressionConfig
fn default() -> CompressionConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CompressionConfig
impl<'de> Deserialize<'de> for CompressionConfig
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CompressionConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CompressionConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompressionConfig
Sourceimpl JsonSchema for CompressionConfig
impl JsonSchema for CompressionConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompressionConfig
impl PartialEq for CompressionConfig
Sourceimpl Serialize for CompressionConfig
impl Serialize for CompressionConfig
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for CompressionConfig