pub struct PartitionConfig {
pub count: Option<u32>,
pub max_size: Option<ByteSize>,
pub replication: Option<u32>,
pub ignore_rack_assignment: Option<bool>,
pub maps: Option<Vec<PartitionMap>>,
}Fields
count: Option<u32>max_size: Option<ByteSize>replication: Option<u32>ignore_rack_assignment: Option<bool>maps: Option<Vec<PartitionMap>>Trait Implementations
Sourceimpl Clone for PartitionConfig
impl Clone for PartitionConfig
Sourcefn clone(&self) -> PartitionConfig
fn clone(&self) -> PartitionConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PartitionConfig
impl Debug for PartitionConfig
Sourceimpl Default for PartitionConfig
impl Default for PartitionConfig
Sourcefn default() -> PartitionConfig
fn default() -> PartitionConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartitionConfig
impl<'de> Deserialize<'de> for PartitionConfig
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PartitionConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PartitionConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PartitionConfig
Sourceimpl JsonSchema for PartitionConfig
impl JsonSchema for PartitionConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PartitionConfig
impl PartialEq for PartitionConfig
Sourceimpl Serialize for PartitionConfig
impl Serialize for PartitionConfig
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for PartitionConfig