pub struct PartitionMap {
pub id: u32,
pub replicas: Vec<i32>,
pub mirror: Option<PartitionMirrorConfig>,
}Fields
id: u32replicas: Vec<i32>mirror: Option<PartitionMirrorConfig>Trait Implementations
Sourceimpl Clone for PartitionMap
impl Clone for PartitionMap
Sourcefn clone(&self) -> PartitionMap
fn clone(&self) -> PartitionMap
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PartitionMap
impl Debug for PartitionMap
Sourceimpl Decoder for PartitionMap
impl Decoder for PartitionMap
Sourceimpl Default for PartitionMap
impl Default for PartitionMap
Sourcefn default() -> PartitionMap
fn default() -> PartitionMap
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartitionMap
impl<'de> Deserialize<'de> for PartitionMap
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PartitionMap, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PartitionMap, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encoder for PartitionMap
impl Encoder for PartitionMap
impl Eq for PartitionMap
Sourceimpl JsonSchema for PartitionMap
impl JsonSchema for PartitionMap
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PartitionMap
impl PartialEq for PartitionMap
Sourceimpl Serialize for PartitionMap
impl Serialize for PartitionMap
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for PartitionMap